/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import { IVpc } from 'aws-cdk-lib/aws-ec2';
import { QueueProcessingFargateService } from 'aws-cdk-lib/aws-ecs-patterns';
import { Bucket } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { BaseClass } from '../../../common/base-class';
export interface LlamaIndexDataLoaderProps {
    /**
     * The directory to build the Docker image
     * @description The directory to build the Docker image.
     * @default __dirname + '/docker'
     */
    readonly dockerImageAssetDirectory?: string;
    /**
     * The default memory
     * @description The default memory.
     * @default 2048
     */
    readonly memoryLimitMiB?: number | undefined;
    /**
     * @description the container's logging level
     * @default 'WARNING'
     */
    readonly containerLoggingLevel?: string;
    /**
     * @description the S3 output to use
     * @default undefined
     */
    readonly outputBucket?: Bucket;
    /**
     * @description the VPC to use
     * @default undefined
     */
    readonly vpc?: IVpc;
    /**
     * Value will be appended to resources name.
     *
     * @default - _dev
     */
    readonly stage?: string;
    /**
     * Enable observability. Warning: associated cost with the services
     * used. Best practive to enable by default.
     *
     * @default - true
     */
    readonly observability?: boolean;
}
export declare class LlamaIndexDataLoader extends BaseClass {
    readonly outputBucket: Bucket;
    readonly queueProcessingFargateService: QueueProcessingFargateService;
    private readonly logBucket?;
    private readonly bucketKey?;
    private readonly dockerImageAssetDirectory;
    private readonly memoryLimitMiB;
    private readonly containerLoggingLevel;
    constructor(scope: Construct, id: string, props: LlamaIndexDataLoaderProps);
}
